showyourself

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 8, 2022 License: BSD-3-Clause Imports: 8 Imported by: 0

README

showyourself

16 color image viewer for the terminal that uses content aware image resizing.

I wanted to develop an image viewer that could be usable from within o, a little editor I wrote that targets VT100 compatible terminal emulators.

The content-aware image resizing changes the image, but keeps the most interesting contents.

Comparison

PNG image The same image in a VT100-compatible terminal emulator, using only 16 colors

General info

Documentation

Index

Constants

This section is empty.

Variables

var DrawRune = '▒'

Functions

func ConvertToNRGBA

func ConvertToNRGBA(img image.Image) (*image.NRGBA, error)

func Draw

func Draw(canvas *vt100.Canvas, m image.Image) error

Draw attempts to draw the given image.Image onto a VT100 Canvas

func LoadImage

func LoadImage(filename string) (*image.NRGBA, error)

LoadImage loads a PNG image and converts it to *image.NRGBA

Types

This section is empty.

Directories

Path Synopsis
cmd
viewpng command

Jump to